#!/usr/local/bin/bash


TODAY=$(date +"%F")
VERSION=3.3
PRODUCT=SASRiskManagementForBanking

if [ $# -ne 2 ]; then
    echo "Usage : `basename $0` <SAS-foundation-root-dir> <SAS-config-dir>"
    echo "e.g. `basename $0` /local/install/SASHome/SASFoundation/9.4 /local/install/SASConfig/Lev1"
    exit 1
fi

SRC=$1
DEST=$2

DESTROOT="$DEST/Applications/$PRODUCT/$VERSION/source"
BACKUP="$DEST/Applications/$PRODUCT/$VERSION/source-pre-$TODAY"
TEMPDEST="$DEST/Applications/$PRODUCT/$VERSION/source-$TODAY"

if [ ! -d $SRC ]; then
    echo "Directory $SRC does not exist."
    exit 1
fi

if [ ! -d $DEST ]; then
    echo "Directory $DEST does not exist."
    exit 1
fi
if [ ! -d $SRC/ucmacros ]; then
    echo "Directory $SRC is not a valid SAS Foundation root location"
    exit 1
fi

if [ ! -d "$DEST/Applications/$PRODUCT" ]; then
    echo "Destination is not a valid SAS configuration directory."
    exit 1
fi

if [ -d $TEMPDEST ]; then
    echo "Hotfix already applied - nothing to do."
    exit 1
fi

mkdir $TEMPDEST

if [ ! -d "$SRC/ucmacros/rmbcomnsvr" ]; then
    echo "Could not find common components - aborting..."
    exit 1
fi
for dvd in rmbcomnsvr rmbfirmmva rmbalmmva rmbmktmva rmbcriskmva; do

    COMP_MACRO_SRC="$SRC/ucmacros/$dvd"
    COMP_MISC_SRC="$SRC/misc/$dvd"

    case "$dvd" in
     rmbcomnsvr) COMP=common
            ;;
     rmbfirmmva) COMP=firmwide
            ;;
     rmbalmmva) COMP=alm
             ;;
     rmbmktmva) COMP=market
            ;;
     rmbcriskmva) COMP=credit
          ;;
     *) echo "not recognized"
        exit 1
     ;;
    esac

    COMPORIG="$DEST/Applications/$PRODUCT/$VERSION/source/$COMP"
    COMPDEST="$TEMPDEST/$COMP"

    if [ -d "$COMP_MACRO_SRC" ]; then
       # copy macros
        mkdir -p $COMPDEST/ucmacros
        cp -r  $COMP_MACRO_SRC/*.sas $COMPDEST/ucmacros
    fi
    
    for misc in batch lua martddl reportmart rptimages sampdata solution_data_mart system_data user_option; do
       if [ -d $COMPORIG/$misc ]; then
            if [ -d "$COMP_MISC_SRC/$misc" ]; then
                cp -r $COMP_MISC_SRC/$misc $COMPDEST
            fi
       fi
    done

    if [ -d $COMPORIG/sasstp ]; then
        if [ -d "$SRC/sasstp/$dvd" ]; then
            mkdir $COMPDEST/sasstp
            cp $SRC/sasstp/$dvd/*.sas $COMPDEST/sasstp
        fi
    fi
done


if [ ! -L $DESTROOT ]; then
    mv $DESTROOT $BACKUP
else
    rm $DESTROOT
fi
ln -s $TEMPDEST $DESTROOT

