-- require rsk_init before anything else in this module is done
require 'sas.risk.rmx.rsk_init'


local errors = require 'sas.risk.utils.errors'

---
-- Override assert so that we can capture the msg value, and later set the key information in the rtmsg_ds with
-- that value (for the mid-tier)
--
local old_assert = assert
--[[assert = function(expr, msg) 
            local success, result = require('sas.risk.utils.errors').protected_call(old_assert, expr, msg)
            if not success then
               if type(result)=="table" then
                  result.msg_key = msg
               else
                  print("result = ", result)
               end
               error({msg_key=msg})
            end
          end
          --]]


local function recover()
   local product_name = sas.symget("PRODUCT")
   assert(product_name, "PRODUCT never set by <rmi|rmb>init macro")
   -- print("product_name=", product_name)
   if not _G.rsk then
      _G.rsk = require("sas.risk.rmx.rsk")
   end
   _G.PROD = require("sas.risk." .. string.lower(product_name) .. '.' .. string.lower(product_name))   

   local last_logged_in_user = tostring(sas.symget("_RSK_LAST_LOGGED_IN_USERNAME"))
   local last_entity = tostring(sas.symget("_RSK_LAST_ENTITY"))
   if last_logged_in_user and #last_logged_in_user > 0 and
      last_entity and #last_entity > 0 and ftn_name ~= "use_entity" then
       
       -- more specific debug msgs are in the individual recover* ftns
       _G.rsk.recover_uec()
       
       if ftn_name ~= "use_playpen" then
          _G.rsk.recover_playpen()
       end
   end
end

local function invoke(mod_name, ftn_name, ...)
   sas.gsymput("_RISKEXEC_RC_", "-1")  -- got here but did not even get to call the requested lua code
   _G.rsk = require("sas.risk.rmx.rsk")
   Debug('Recovering Lua state prior to running ' .. mod_name .. '.' ..  ftn_name .. '  ...')
   recover()
   local real_invoker = require('sas.risk.utils.generic_module_function_invoker')
   real_invoker.invoke(mod_name, ftn_name, ...)
end

return { recover=recover,invoke=invoke }
